@@ -1,7 +1,7 @@
 // qsynthAboutForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2016, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -40,8 +40,8 @@ qsynthAboutForm::qsynthAboutForm (
 	QString sText = "<p align=\"center\"><br />\n";
 	sText += "<b>" QSYNTH_TITLE " - " + tr(QSYNTH_SUBTITLE) + "</b><br />\n";
 	sText += "<br />\n";
-	sText += tr("Version") + ": <b>" QSYNTH_VERSION "</b><br />\n";
-	sText += tr("Build") + ": " __DATE__ " " __TIME__ "<br />\n";
+	sText += tr("Version") + ": <b>" CONFIG_BUILD_VERSION "</b><br />\n";
+	sText += "<small>" + tr("Build") + ": " CONFIG_BUILD_DATE "<small><br />\n";
 #ifdef CONFIG_DEBUG
 	sText += "<small><font color=\"red\">";
 	sText += tr("Debugging option enabled.");
