@@ -1,7 +1,7 @@
 // qsynthMainForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2016, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -148,9 +148,11 @@ protected:
 
 	void setEngineGain(qsynthEngine *pEngine, float fGain);
 	void setEngineReverbOn(qsynthEngine *pEngine, bool bActive);
-	void setEngineReverb(qsynthEngine *pEngine, float fRoom, float fDamp, float fWidth, float fLevel);
+	void setEngineReverb(qsynthEngine *pEngine,
+		double fRoom, double fDamp, double fWidth, double fLevel);
 	void setEngineChorusOn(qsynthEngine *pEngine, bool bActive);
-	void setEngineChorus(qsynthEngine *pEngine, int iNr, float fLevel, float fSpeed, float fDepth, int iType);
+	void setEngineChorus(qsynthEngine *pEngine,
+		int iNr, double fLevel, double fSpeed, double fDepth, int iType);
 
 	void loadPanelSettings(qsynthEngine *pEngine, bool bUpdate);
 	void savePanelSettings(qsynthEngine *pEngine);
