@@ -72,6 +72,7 @@ void qsynthOptions::loadOptions (void)
 	bOutputMeters   = m_settings.value("/OutputMeters", false).toBool();
 	bSystemTray     = m_settings.value("/SystemTray", false).toBool();
 	bSystemTrayQueryClose = m_settings.value("/SystemTrayQueryClsoe", true).toBool();
+	bStartMinimized = m_settings.value("/StartMinimized", false).toBool();
 	iBaseFontSize   = m_settings.value("/BaseFontSize", 0).toInt();
 	iKnobStyle      = m_settings.value("/KnobStyle", 0).toInt();
 	iKnobMotion     = m_settings.value("/KnobMotion", 1).toInt();
@@ -102,7 +103,7 @@ void qsynthOptions::saveOptions (void)
 {
 	// Make program version available in the future.
 	m_settings.beginGroup("/Program");
-	m_settings.setValue("/Version", QSYNTH_VERSION);
+	m_settings.setValue("/Version", CONFIG_BUILD_VERSION);
 	m_settings.endGroup();
 
 	// Save engines list...
@@ -137,6 +138,7 @@ void qsynthOptions::saveOptions (void)
 	m_settings.setValue("/OutputMeters", bOutputMeters);
 	m_settings.setValue("/SystemTray", bSystemTray);
 	m_settings.setValue("/SystemTrayQueryClose", bSystemTrayQueryClose);
+	m_settings.setValue("/StartMinimized", bStartMinimized);
 	m_settings.setValue("/BaseFontSize", iBaseFontSize);
 	m_settings.setValue("/KnobStyle", iKnobStyle);
 	m_settings.setValue("/KnobMotion", iKnobMotion);
@@ -364,10 +366,15 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 			return false;
 		}
 		else if (sArg == "-V" || sArg == "--version") {
-			out << QObject::tr("Qt: %1\n").arg(qVersion());
-			out << QObject::tr(QSYNTH_TITLE ": %1\n").arg(QSYNTH_VERSION);
+			out << QObject::tr("Qt: %1\n")
+				.arg(qVersion());
+			out << QObject::tr("%1: %2  (%3)\n")
+				.arg(QSYNTH_TITLE)
+				.arg(CONFIG_BUILD_VERSION)
+				.arg(CONFIG_BUILD_DATE);
 			return false;
-		} else {
+		}
+		else {
 			const QByteArray tmp = args.at(i).toUtf8();
 			const char *name = tmp.constData();
 			if (::fluid_is_soundfont(name)) {
@@ -903,7 +910,7 @@ void qsynthOptions::loadWidgetGeometry ( QWidget *pWidget, bool bVisible )
 		pWidget->adjustSize();
 		if (!bVisible)
 			bVisible = m_settings.value("/visible", false).toBool();
-		if (bVisible)
+		if (bVisible && !bStartMinimized)
 			pWidget->show();
 		else
 			pWidget->hide();
@@ -930,7 +937,7 @@ void qsynthOptions::saveWidgetGeometry ( QWidget *pWidget, bool bVisible )
 		m_settings.setValue("/height", wsize.height());
 	#endif
 		if (!bVisible) bVisible = pWidget->isVisible();
-		m_settings.setValue("/visible", bVisible);
+		m_settings.setValue("/visible", bVisible && !bStartMinimized);
 		m_settings.endGroup();
 	}
 }
